@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_master - remote control master for Nokia N900 phone #
-# $Id: smscon_master.py 33 2011-12-17 23:50:16Z yablacky $
+# $Id: smscon_master.py 49 2011-12-20 04:12:15Z yablacky $
 ##############################################################
 
 import os
@@ -340,7 +340,9 @@ def main():
     global LOGGER, ourConf, daemon, settingsChangeCount
 
     if os.geteuid() != 0 and not XDEBUG:
-        print 'ERROR: %s must run as "root". You are currently not "root".' % NAME
+        os.execvp("sudo", ["sudo"] + sys.argv)
+        # We get here on failure only!
+        print 'ERROR: %s must run as "root". Try sudo command prefix to elevate your rights.' % NAME
         sys.exit(1)
 
     LOGGER = StartLogging('SMSCON', withConsole = True)
@@ -349,7 +351,7 @@ def main():
     if ourConf.load(Silent = True) or ourConf.needsUpgrade():
         ourConf.upgrade()
 
-    daemon = smscon_deamon()
+    daemon = smscon_daemon()
     settingsChangeCount = 0
 
     ok = DoCommandLine()
