@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 74 2011-12-23 01:10:39Z yablacky $
+# $Id: smscon_service.py 78 2011-12-23 23:12:29Z yablacky $
 ##############################################################
 
 # standard modules
@@ -57,6 +57,8 @@ IsKeyboardSliderCheckActive = False
 IsBatteryStatusCheckActive  = False
 IsCheckHostActive           = False
 
+LastBatteryStatusMessage    = None
+
 CheckHostLastCommand        = '-1'      # "restart"
 CheckHostStatusCount        = 0         # positive: successes, negative: errors
 CheckHostStatusTimestamp    = time.gmtime()
@@ -656,7 +658,6 @@ def PerformAlarm():
                       /com/nokia/profiled \
                       com.nokia.profiled.get_profile').read()
     E = re.compile('string "(\S+)"')
-
     try:
         CurrentProfile = E.findall(Output)[0]
     except Exception, e:
@@ -710,7 +711,7 @@ def PlayAudio(AudioFilename, PrePlayCommand = None, PostPlayCommand = None):
 
 def EnableDeviceSilence(Enable = True):
     """
-    Make the phone silent for email, instand-messaging, phone ringing & SMS.
+    Make the phone silent for email, instant-messaging, phone ringing & SMS.
     """    
 
     if not Enable:
@@ -729,19 +730,13 @@ def EnableDeviceSilence(Enable = True):
                       /com/nokia/profiled \
                       com.nokia.profiled.get_profile').read()
     E = re.compile('string "(\S+)"')
-
-    if E:
-        LOGGER.debug('(SILENCE) CurrentProfile = %s.' % E.findall(Output) )
-        try:
-            CurrentProfile = E.findall(Output)[0]
-        except:
-            LOGGER.error('(SILENCE) Could not get current phone profile')
-            return
-        else:
-            LOGGER.info('(SILENCE) Current profile is "%s".' % CurrentProfile)
-    else:
-        LOGGER.error('(SILENCE) Could not get current phone profile.')
+    try:
+        CurrentProfile = E.findall(Output)[0]
+    except Exception, e:
+        LOGGER.error('(SILENCE) Could not get current phone profile: %s' % e)
         return
+    else:
+        LOGGER.info('(SILENCE) Current profile is "%s".' % CurrentProfile)
 
     # set items in current profile
     for Key, Value in KeyList:
@@ -1101,7 +1096,7 @@ def GetWLANname():
     NetworkList = GetNetworks()
 
     # get last used data network IAP
-    LastUsedNetwork = os.popen(' gconftool -g /system/osso/connectivity/IAP/last_used_network').read().strip('\n')
+    LastUsedNetwork = os.popen('gconftool -g /system/osso/connectivity/IAP/last_used_network').read().strip('\n')
     LOGGER.debug('LastUsedNetwork = [%s].' % LastUsedNetwork)
 
     for Network in NetworkList:
@@ -1261,20 +1256,21 @@ def SetAutoConnectBehaviour(NewBehaviour):
 #   power status
 #############################################
 
-def GetBatteryChargeInfo(TextOnly = True):
+def GetBatteryChargeInfo(TextOnly = True, ChargePercentMin = 10):
     """
     Determine battery charge info.
+    @param bool TextOnly
+    @param int ChargePercentMin Warn if battery change level is below this value.
     @return string Charge info text or
     @return (string, number, bool) if TextOnly is false.
     """
     global dev_obj
-    chargePercentMin = 10
 
     # Try getting charge info, not all devices support all properties: 
     try:
         chargePercent = dev_obj.GetProperty('battery.charge_level.percentage')  # charge amount of battery in percentage
         chargePercentText = '%s%%' % chargePercent
-        chargeHint = IF(chargePercent > chargePercentMin, '', ' (almost empty!)')
+        chargeHint = IF(chargePercent >= ChargePercentMin, '', ' (almost empty!)')
     except Exception, e:
         LOGGER.warning('%s' % e)
         chargePercent = None
@@ -1283,13 +1279,13 @@ def GetBatteryChargeInfo(TextOnly = True):
 
     try:
         isCharging = dev_obj.GetProperty('battery.rechargeable.is_charging') # charging: 1 / discharging: 0
-        isChargingText = IF(isCharging, 'charging', 'discharging')
+        isChargingText = IF(isCharging, ', charging', ', discharging')
     except Exception, e:
         LOGGER.warning('%s' % e)
         isCharging = None
         isChargingText = ''
 
-    Text = 'Phone battery charge is %s, %s%s.' % (chargePercentText, isChargingText, chargeHint)
+    Text = 'Phone battery charge is %s%s%s.' % (chargePercentText, isChargingText, chargeHint)
     if TextOnly: return Text
     return (Text, chargePercent, isCharging)
 
@@ -1759,7 +1755,7 @@ def RestartDaemon():
     LOGGER.critical('(RESTART) %s tries to restart itself w/o regular stop.' % DaemonFile)
     try:
         time.sleep(DelaySeconds)
-        os.system( '"%s" -restart' % os.path.join(InstPath, smscon.NAME) )
+        os.system( '%s -restart' % shellArg(os.path.join(InstPath, smscon.NAME)) )
     finally:
         LOGGER.critical('(RESTART) Not restarted. Failed to kill %s.' % DaemonFile)
 
@@ -1772,8 +1768,13 @@ def OnKeyboardSliderChange(Action, Type):
     Check and reveal state of keyboard slider.
     @return void. 
     """
-    KeyState = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read().strip('\n') 
-    RevealThat('Keyboard', 'Phone is being used: keyboard now %s.' % str(KeyState))            
+    try:
+        SliderState = open('/sys/devices/platform/gpio-switch/slide/state').read().strip()
+    except Exception, e:
+        LOGGER.error('Failed to detect keyboard slider state: %s' % e)
+        SliderState = 'in unknown state'
+    LOGGER.info('Phone is being used: keyboard now %s.' % SliderState)
+    RevealThat('Keyboard', 'Phone is being used: keyboard now %s.' % SliderState)            
 
 #############################################
 #   battery charge (dbus trigger)
@@ -1784,10 +1785,15 @@ def OnBatteryStatusChange(BarLevel, BarLevelMax):
     Check and reveal battery charge level.
     @return void. 
     """
-    Message, ChargePercent, Charging = GetBatteryChargeInfo(TextOnly = False)        
-    LOGGER.info(Message)
-    if (Charging != None and not Charging) or (ChargePercent != None and ChargePercent < 10): 
-        RevealThat('battery warning', Message)
+    global LastBatteryStatusMessage
+    ChargePercentMin = 10
+    Message, ChargePercent, Charging = GetBatteryChargeInfo(TextOnly = False, ChargePercentMin = ChargePercentMin)        
+
+    if Message != LastBatteryStatusMessage:
+        LastBatteryStatusMessage = Message
+        LOGGER.info(Message)
+        if (Charging != None and not Charging) or (ChargePercent != None and ChargePercent < ChargePercentMin): 
+            RevealThat('battery warning', Message)
 
 #############################################
 #   remote host file checking (remote smscon trigger)
@@ -2035,217 +2041,4 @@ def main():
 #############################################
 
 """
-
- 0.9.1
- REFACTURING:
-         * Extracted common code to a library (smsconlib.py) which is now used by
-           smscon_daemon, smscon control program and smscon-editor.
-         * Added a lot of code comments.
-         * Encapsulated many code into classes. E.g. the complete encyption stuff
-           is now transparent to smscon control program and smsmcon editor.
-         * Restructured code, written new and renamed a lot of old stuff.
-         * Moved code from files "smscon" and "smscon_daemon" to pure
-           python-modules (smscon_master.py and smscon_service.py respectively).
-           The original files are now just jackets calling main() in associated
-           python module. This allows to compile the modules and hiding source code.
- NEW:    Encryption now uses salt (formerly encrypted data can be read).
- FIX:    Encryption does no longer fail on text ending with curly open brace.
- NEW:    "MASTERNUMBER" concept: A SMS number stored in the config file that
-         does NOT change due to SMS commands like "SENDERNUMBER" does.
-         Each SMS is send to both (only once if they are the same numbers, of course).
-         SMS replies to commands which are not introduced by SMS (e.g. via CHECKHOST)
-         are sent to the MASTERNUMBER only.
-         On upgrading, the default MASTERNUMBER is set to the current SENDERNUMBER.
- NEW:    "COM_CUSTOMLOG" command: A SMS command to retreive the output of the last
-         "COM_CUSTOM" command. Will be sent via email only - would send too much SMS...
- NEW:    "COM_LOG" command: A SMS command to retreive the smscon.log file.
-         Will be sent via email only - would send too much SMS...
- NEW:    The output of "COM_SHELL" SMS command is now sent as a command reply.
-         You may have to remove output redirections from your shell command to
-         get non-empty reply.
- NEW:    "SMS_PARTS_LIMIT": A number to limit the number of single SMS that would
-         otherwise be generated to send a too long SMS message. Zero means no limit.
- NEW:    "LOG_TIMEFORMAT": Format to be used in time stamps of SMS and EMAIL messages.
- NEW:    "SMS_COMPREFIX" and "SMS_COMSUFFIX": Instead of explicitly define
-         all your SMS control commands (COM_xxx) to start with a unique prefix
-         and/or suffix, you might now separately define a prefix and/or suffix
-         that is implicitely used. While "SMS_COMPREFIX" and "SMS_COMSUFFIX" are
-         empty, all your commands do as in older versions.
-         Advantage of using "SMS_COMPREFIX" and "SMS_COMSUFFIX":
-         * Prefix and suffix can be changed easyly while embedded COM_xxx remain unchanged.
-         * Prefix and suffix apply to COM_SHELL command as well. Example:
-             With the configuration set to:
-                 COM_SHELL=uptime
-                 SMS_COMPREFIX=aaa.
-                 SMS_COMSUFFIX=.bbb
-             The recognized SMS command to execute the shell command "uptime" is:
-                 aaa.uptime.bbb
- FIX:    It is no longer possible to define two SMS commands as the same string except
-         the empty string, which means to disable that command being given via SMS.
- FIX:    SMS command recognition is no longer restricted to ASCII characters.
-         The complete GSM 7 bit default alphabet may be used now (but not unicode).
-         This gives you a greather variete of chars to use for your SMS commands.
- NEW:    The config file will now upgrade automagically from any previous version.
-         New options are set to their default, obsolete options are commented out.
- NEW:    New function to export and import settings to/from arbitrary file.
-         (see smscon -export and -import options). smscon editor makes
-         now use of this functions to retrieve a and deploy editable configuration.
- NEW:    The smscon_daemon does no longer need to be restarted explicitly if
-         smscon changes a setting. The daemon detects changes automagically and
-         will read and apply the new configuration automatically.
- NEW:    The smscon_daemon now maintains a "last known good" configuration and uses
-         that as a fallback in case the "official" configuration of smscon can't
-         properly loaded by the daemon.
- NEW:    Camera picture and GSP Location requests do no longer force unconditional
-         switching to GPRS network connection. The current connection will be used
-         if the internet is reachable.
-         Should a GPRS connection be required to reach internet, the GPRS
-         connection is established but the previous network is re-activated
-         after picture and/or location has been replied.
- NEW:    A LOGGER is now used wherever possible. So the smscon.log file becomes
-         really interesting.
- NEW:    The "CHECKHOST" URL is now extended by "?LASTMCD=nn&CHECKTIME=minutes"
-         which will allow the URL being a script that may use this information.
- CHANGE: "CHECKHOST" now works more clear as follows: While polling for
-         commands, a command is executed once, if it differs from the
-         last polled command. The last polled command is initialized
-         to "-1" on daemon start. Code "-1" is "restart daemon" and
-         this obviously is what happened on daemon start.
-         Code "17" (COM_RESTART) is deprecated as a CHECKHOST command.
-         Since it is different from "-1" it may restart the daemon repeatedly.
-         Use code "-1" to restart the daemon via CHECKHOST instead. Of course,
-         before a change to code "-1" is recognized by the daemon, you must
-         have give it a different command code. If in doubt use "01" (COM_CHECK)
-         because it gives you feedback that the command has been seen.
- CHANGE: "CHECKTIME" may now be a float to specify fractional parts
-         of a minute: 0.25 is 15 seconds.  
- NEW:    The "CHECKHOST" URL may now have a protocol prefix and it may be
-         different from "http://". If the URL has no protocol prefix, then
-         "http://" is supplied as default as in former versions (e.g. your
-         config file remains valid in this point as well).
- NEW:    The battery status is logged before a command is about to be executed.
- NEW:    "REMOTELISTENIP", "REMOTELISTENPORT" and "REMOTE2LOCALPORT": These
-         settings give you greather flexibility of setting up a tunnel to
-         remote control your phone via a reverse ssh-connection:
-         Use "REMOTELISTENIP" and "REMOTELISTENPORT" to define the tunnel
-         entry maintained by the remote ssh-server (which must be setup to
-         allow setting LISTENIP and PORT this way).
-         "REMOTELISTENPORT" defaults to 8080 and "REMOTELISTENIP" defaults
-         to "localhost" as in former versions. With these defaults you must
-         be logged in at the ssh-server to start a remote control connection
-         of your phone. While setting up "REMOTELISTENIP" you may even
-         control the phone from somewhere else (in which case the ssh-server
-         act as a proxy or relay). On the tunnel exit side, which is on your
-         phone, the "REMOTE2LOCALPORT" is the port number where your phone's
-         ssh-daemeon is listening (usually 22).
- CHANGE: The "smscon -devconfig" command now requires a password to show the
-         uncrypted configuration. The MASTERNUMBER is the password.
- NEW:    "RESENDMAXTRY": This option defines the maximum number of message
-         re-send tries. Applies to SMS and EMAIL as well. (0=no limit)
-         On configuration upgrade this is initialized to 10.
- NEW:    smscon now has a -sendsms option to send SMS immediately.
-         Despite being a nice feature by itself, it makes smscon editor
-         independent from smssend program which requires an extra package.
-
- 0.8.1-1
- FIX: shutdown & reboot routine (PerformPoweroff & PerformReboot) give internal error.
- NEW: added remote activation of smscon_daemon; content of file CHECKHOST (hostname+filename)
-      on server will be checked every CHECKTIME minutes. If other then 0 it will execute the corresponding command.
-
- 0.8.0-1
- NEW/CHANGE: expanded user setting MESSAGESEND ('sms', 'email', 'both' & 'none').
-             removed DISABLESMS user setting. This is superseded by MESSAGESEND user setting!
-             SIM card change SMS always will be send regardless of MESSAGESEND setting.
- NEW: added smscon command (RESTART); user can restart smscon_daemon by SMS command.
- NEW: added smscon command (COM_ALARM); phone will play user configurable sound file (only WAV!) when command is received. 
- NEW: smscon_daemon sends SMS/email message if smscon_daemon crashes.
- CHANGE: changed user setting ENABLERESEND ('yes', 'no'). Resending of messages will again be experimental feature!!!
- CHANGE: removed MAXRESEND user setting (didn't work properly).
- CHANGE: some log text changed/added.
- CHANGE: removed updatechecker during installation of smscon (failed to work previously).
- CHANGE: some changes in GPS message sending code.
- CHANGE: AUTODEVICELOCK message is only send if COMMANDREPLY is enabled.
- FIX: small bug in SMSsend().
- FIX: bug in GPSINTERVAL handeling; GPSINTERVAL was always set at 60 sec. regardless of user setting.
-
- 0.7-2
- FIX: bug in RestoreNetworkSettings(); (None must be 'NONE').
- FIX: bug in heckArguments(); EnableScript() must be PerformShellScript().
- EXPERIMENTAL: updatechecker to save "smscon_config" file when updating to new version.
- 
- 0.7-1
- NEW: multiple IMSI codes are allowed in smscon_code file; use new option "smscon -add imsi" to store current IMSI code in smscon_code file.
- NEW: added new user option (DISABLESMS); WARNING: disables ALL SMS sending in smscon program.
- NEW: added new smscon command (COM_SHELL); run directly shell commands. (no check & feedback from command!).
- NEW: added new user option (SIMUNLOCK); auto unlock phone after new SIM is inserted (to fool a possible thief of your phone).
- NEW: added new user option (SILENCEDEVICE); disable all phone sounds (calendar alarm, clock, email alert, IM alert, ringing alert & SMS alert) if smscon is active.
- NEW/CHANGE: new user option (AUTOBATREPORT); user can enable/disable sending automatically a SMS message when smscon is activated & device battery is depleting.
- CHANGE: when initializing a new smscon_config file all user settings wil be set default to 'no'.
- REFACTORING: some parts in both scripts.
- FIX: better number handeling in SMSrecieve() routine (thanks to maemo.org user!).
- FIX: small bug in GSMmodem() in smscon_daemon script.
- FIX: small text bug in smscon script
-
- EXPERIMENTAL/CHANGE: when smscon fails to send SMS message (no cell reception) it will retry after 900 seconds.
- EXPERIMENTAL/FIX: change in getting the right GPRS connections; MMS & WAP will be discarded in available GPRS network list.
-    
- 0.5-9
- NEW: added new smscon command: COM_CUSTOM to run a user configurable shell script (/opt/smscon/smscon_script)
- NEW: if user setting REMOTEUSER, REMOTEPASSWORD is empty, "Remoteon" & "Remoteoff" function is disabled in smscon. 
- NEW: smscon will send automatically a SMS message when smscon is activated & device battery is depleting.
- CHANGE: added new options in smscon menu.
- CHANGE: added time notation in GPS email & SMS messages.
- CHANGE: improved the way smscon reads user settings from smscon_config file.
- EXPERIMENTAL/CHANGE: when smscon fails to send SMS message (no cell reception) it will retry after 900 seconds.
- EXPERIMENTAL/FIX: change in getting the right GPRS connections; MMS & WAP will be discarded in available GPRS network list.
- FIX: picture of frontcam & GoogleMap image are named wrong & placed therefore in wrong directory.
- FIX: smscon fails to send SMS message when message is too long (> 160 chars.)
- FIX: "smscon -test2" test function would fail if a valid smscon command has spaces in it. /*Developer usage only*/
-
- 0.5-8 /* UNRELEASED VERSION */
- NEW: smscon will send automatically a SMS message when smscon is activated & device battery is depleting.
- CHANGE: added time notation in GPS email & SMS messages.
- EXPERIMENTAL/FIX: change in getting the right GPRS connections; MMS will be discarded in available network list. 
- FIX: smscon fails to send SMS message when message is too long.
- FIX: "smscon -test2" test function would fail if a valid smscon command has spaces in it.
-
- 0.5-7
- FIX: activation of the current active/available GPRS connection could fail in specific cases (bug in acquiering the syntax correct name).
- FIX: better logging/behaviour when locking/unlocking of device.
-
- 0.5-6
- NEW: added new command-line option for smscon to set user settings (encrypted & non-encrypted) in smscon_config file.
- NEW: added package icon
- CHANGE: improved user setting reading from smscon_config file.
- CHANGE: cosmetic changes in LOGGER.
- REFACTORING: parts of script code.
- FIX: smscon can send to wrong phone number when activated.
- FIX: added time & date of frontcam picture taken in email.
-
- 0.5-5
- NEW: new test mode for simulating all smscon commands. /*Developer usage only*/
- NEW: in reply SMS from COM_LOCATION command is http link added to GoogleMaps.
- NEW/CHANGE: optification of smscon; new install path of package is now /opt/smscon.
- REFACTORING: improved the way SMS is send (more stable).
- CHANGE: in smscon test modes usage of WLAN connection only if already connected, otherwise usage of GPRS.
- CHANGE: in smscon test modes if usage of GPRS connection, previous connection is saved & re-enabled after GPRS usage.
- CHANGE: if usage of GPRS connection, force Internet connections to GPRS connection (needed for keeping the connection alive/stable).
- CHANGE: new smscon icon (meets requirements of maemo package)
- CHANGE: new package description (meets requirements of maemo Extra-testing package)
- FIX: execption in email sending code failed.
- FIX: internal fixes (better consistency in logging).
- FIX: email attachment (camera picture or Google map) is displayed completely wrong (alt text was wrong/mixed etc.)
- FIX: remove unused variable in ConfigVars list.
- FIX: syntax bug fixed which could crash smscon.
-
- 0.4.4-6
- NEW: GPSSEND has new extra option 'both'. (options are now: 'sms' / 'email' / 'both')
-
- 0.4.4-5
- NEW: COM_CHECK returns all valid SMS commands
- NEW: improved email smtp server handling
- FIX: ssh connection passfrase for auth. keys added
- FIX: "Internet connection" behavior set to initial setting when smscon_daemon stops.
- FIX: email sending works with or without secure authentication (tested with Google gmail)
-"""
-
+"""
\ No newline at end of file
