@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 74 2011-12-23 01:10:39Z yablacky $
+# $Id: smsconlib.py 77 2011-12-23 23:09:47Z yablacky $
 ##############################################################
 
 # standard modules
@@ -21,7 +21,7 @@ def getSysBuildNameAndVersion(defaultName, defaultVersion = '999.1', headerInfo
     Analyze information from version control system to find out name and version of a branch.
     @param string defaultName Name to return if version information not recognized.
     @param string defaultVersion Version to return if version information not recognized.
-    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.5/src/opt/smscon/smsconlib.py 74 2011-12-23 01:10:39Z yablacky $ keyword to be analyzed.
+    @param string headerInfo Value from expanded $Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.6/src/opt/smscon/smsconlib.py 77 2011-12-23 23:09:47Z yablacky $ keyword to be analyzed.
     @param int dirLevel Number of extra dirs to walk up to find the one that contains version information (0 = parent dir).
     @return list (name, version) The name and version information.
     """
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.5/src/opt/smscon/smsconlib.py 74 2011-12-23 01:10:39Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.6/src/opt/smscon/smsconlib.py 77 2011-12-23 23:09:47Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -129,11 +129,11 @@ def pidof(ProcessName):
     Determine the PID of processes that match a given name.
     @return string Whitespace separator PID. Empty if none.
     """
-    PIDs = os.popen('pidof %s' % shellArg(ProcessName)).read().strip('\n')
+    PIDs = os.popen('pidof %s' % shellArg(ProcessName)).read().strip()
     if PIDs != '':
         return PIDs
     PIDs = []
-    for psLine in os.popen('ps|grep -v grep|grep %s' % shellArg(' ' + ProcessName)).readlines():
+    for psLine in os.popen('ps|grep -v grep|grep %s' % shellArg(ProcessName)).readlines():
         PIDs.append(psLine.split()[0])
     return ' '.join(PIDs)
 
